@@ -1,10 +1,10 @@
-#!/usr/bin/python
 #
-# Copyright (c) 2017-2019 NVIDIA CORPORATION. All rights reserved.
-# This file is part of the objectio library.
+# Copyright (c) 2017-2021 NVIDIA CORPORATION. All rights reserved.
+# This file is part of the webdataset library.
 # See the LICENSE file for licensing terms (BSD-style).
 #
 
+"""A collection of simple runtime checks."""
 
 
 def checktype(value, types, msg=""):
